unit MakeNamesUnit;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, ComCtrls;

type
  TNamesForm = class(TForm)
    RichEdit: TRichEdit;
    NamesButton: TButton;
    CountEdit: TEdit;
    OpenDialog: TOpenDialog;
    SaveDialog: TSaveDialog;
    Label1: TLabel;
    procedure NamesButtonClick(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

var
  NamesForm: TNamesForm;

implementation

{$R *.DFM}
(*********************************************************************)
(* Assume the form of S is Last Name, comma, space, first name.      *)
(* SplitName divides S into its components, FName and LName          *)
(*********************************************************************)
procedure SplitName(const S: string; var FName, LName: string);
  var J, K: integer;
begin
  J := 1;
  LName := '';
  while S[J] <> ',' do  // Last name everything to comma
    begin
    LName := LName + S[J];
    inc(J);
    end;

  inc(J);  // skip comma
  inc(J);  // skip space

  FName := '';
  for K := J to length(S) do  // First name is everything else
    FName := FName + S[K];
end;




(*********************************************************************)
(* Choose a file that contains a list of names in the form last name,*)
(* comma, space, and first name.  Read from that list of names, split*)
(* the names into their components and create a list of the first    *)
(* names and a list of the last names.  Then reassemble them into a  *)
(* large array of new names where the first and last names are       *)
(* choosen randomly from the lists first and last names.             *)
(*                                                                   *)
(* The resulting file can be used as a set of test data.             *)
(*********************************************************************)
procedure TNamesForm.NamesButtonClick(Sender: TObject);
var LastName, FirstName: array [0..1000] of string;
    RandomName: array of string;
    Name: string;
    NameFile: TextFile;
    Count, J, Size: integer;
begin
// convert CountEdit to an integer.  Exit if invalid
try
  Size := StrToInt(CountEdit.Text);
except
  ShowMessage('Number of names must be an integer');
  exit
end;

// ParamStr(0) is the complete file name of the executable of this program
// ExtractFileDir returns the directory of its parameter.

// Set the default directory to the path of this program.
OpenDialog.InitialDir := ExtractFileDir(ParamStr(0));
if OpenDialog.Execute then
  begin
  // open input file
  AssignFile(NameFile, OpenDialog.FileName);
  Reset(NameFile);

  Count := 0;
  while (Count <= 1000) and not eof(NameFile) do
    begin
    // read and split each name in the input file
    Readln(NameFile, Name);
    SplitName(Name, FirstName[Count], LastName[Count]);
    RichEdit.Lines.Add(FirstName[Count] + ' ' + LastName[Count]);
    Inc(Count);
    end;

  CloseFile(NameFile);  // close input file

  Randomize;

  // set default directory to the same as the input file
  SaveDialog.InitialDir := ExtractFileDir(OpenDialog.FileName);
  if SaveDialog.Execute then
    begin
    // open output file
    AssignFile(NameFile, SaveDialog.FileName);
    Rewrite(NameFile);

    // write required number of random names to file
    for J := 1 to Size do
      Writeln(NameFile, LastName[Random(Count)] +
                        ', ' + FirstName[Random(Count)]);

    // close output file
    CloseFile(NameFile);

    ShowMessage(CountEdit.Text + ' random names have been save in the file '
        + SaveDialog.FileName);
    end;
  end;
end;

end.
